analphipy.Phi\_yk
=================

.. currentmodule:: analphipy

.. autoclass:: Phi_yk

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~Phi_yk.__init__
      ~Phi_yk.asdict
      ~Phi_yk.assign
      ~Phi_yk.assign_min_numeric
      ~Phi_yk.cut
      ~Phi_yk.dphidr
      ~Phi_yk.lfs
      ~Phi_yk.minimize
      ~Phi_yk.new_like
      ~Phi_yk.phi
      ~Phi_yk.to_measures
      ~Phi_yk.to_nf
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree:
   
      ~Phi_yk.z
      ~Phi_yk.sig
      ~Phi_yk.eps
      ~Phi_yk.phi_min
      ~Phi_yk.r_min
      ~Phi_yk.segments
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~Phi_yk.__repr__
   
   